__title__ = 'samanage-py'
__description__ = 'A package to easily connect to Samanage API' 
__url__ = 'https://github.com/rodneymandap/samanage-py'
__version__ = '0.1.8'
__author__ = 'Rodney Jan Mandap'
__author_email__ = 'rodneyjan.mandap@gmail.com'
__copyright__ = 'Copyright (c) 2021 Rodney Jan Mandap'
